<?php

namespace Modules\Laundry\Entities;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Builder;
use Modules\Laundry\Entities\InventoryItem;

class Inventory extends Model
{
    protected $table = 'laundry_inventories';

    public static function booted()
    {
        static::addGlobalScope('business_check', function (Builder $builder) {
            $builder->where('business_id', auth()->user()->business_id);
        });
    }

    public function setCategoryIdAttribute($value){
        $this->attributes['business_id'] = auth()->user()->business_id;
        $this->attributes['category_id'] = $value;
    }
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'category_id',
        'subcategory_id',
        'brand_id',
        'supplier_id',
        'customer_id',
        'washing_cost',
        'washing_cycle',
        'business_id'
    ];

    public function business()
    {
        return $this->belongsTo(Business::class);
    }

    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }
    public function subcategory()
    {
        return $this->belongsTo(Subcategory::class, 'subcategory_id');
    }
    public function brand()
    {
        return $this->belongsTo(Brand::class, 'brand_id');
    }
    public function supplier()
    {
        return $this->belongsTo(Supplier::class, 'supplier_id');
    }
    public function customer()
    {
        return $this->belongsTo(Customer::class, 'customer_id');
    }
    public function items()
    {
        return $this->hasMany(InventoryItem::class);
    }
    public function getQuantityAttribute(){
        return InventoryItem::where('inventory_id', $this->id)->count();
    }
}
