<?php

namespace Modules\Laundry\Entities;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Builder;

class InventoryItem extends Model
{
    protected $table = 'laundry_inventory_items';

    public static function booted()
    {
        static::addGlobalScope('business_check', function (Builder $builder) {
            $builder->where('business_id', auth()->user()->business_id);
        });
    }

    public function setRfidAttribute($value){
        $this->attributes['business_id'] = auth()->user()->business_id;
        $this->attributes['rfid'] = $value;
    }
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'id',
        'rfid',
        'user_id',
        'inventory_id',
        'isActive',
        'business_id'
    ];

    public function business($isSuperAdmin=false)
    {
        if($isSuperAdmin)
        return $this->belongsTo(Business::class)->withoutGlobalScope('business_check');
        else
        return $this->belongsTo(Business::class);
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function inventory($isSuperAdmin=false)
    {
        if($isSuperAdmin)
        return $this->belongsTo(Inventory::class, 'inventory_id')->withoutGlobalScope('business_check');
        else
        return $this->belongsTo(Inventory::class, 'inventory_id');
    }

    public function process_stock($isSuperAdmin=false)
    {
        if($isSuperAdmin)
            return $this->hasMany(ProcessStock::class)->withoutGlobalScope('business_check');
        else
            return $this->hasMany(ProcessStock::class);
    }

    public function process_stock_washing($isSuperAdmin=false)
    {
        if($isSuperAdmin)
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','washing')->withoutGlobalScope('business_check');
        else
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','washing');
    }

    public function process_stock_lost_damage($isSuperAdmin=false)
    {
        if($isSuperAdmin)
        return $this->hasMany(ProcessStock::class)->withoutGlobalScope('business_check')
            ->where(function($query){
            $query->where('laundry_process_stocks.status','lost')
                ->orWhere('laundry_process_stocks.status','damaged');
        });
        else
        return $this->hasMany(ProcessStock::class)->where(function($query){
            $query->where('laundry_process_stocks.status','lost')
                ->orWhere('laundry_process_stocks.status','damaged');
        });
    }

    // for Launder
    public function process_stock_received($isSuperAdmin=false)
    {
        if($isSuperAdmin)
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','received')->withoutGlobalScope('business_check');
        else
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','received');
    }

    public function process_stock_washed($isSuperAdmin=false)
    {
        if($isSuperAdmin)
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','washed')->withoutGlobalScope('business_check');
        else
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','washed');
        // return $this->hasMany(ProcessStock::class)->whereRaw('id = (SELECT MAX(id) FROM laundry_process_stocks WHERE rfid = rfid)')->where('status','washed');
    }
    
    public function process_stock_sent($isSuperAdmin=false)
    {
        if($isSuperAdmin)
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','sent')->withoutGlobalScope('business_check');
        else
        return $this->hasMany(ProcessStock::class)->where('laundry_process_stocks.status','sent');
    }

}
