<?php

namespace Modules\Laundry\Entities;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Builder;

class ProcessStock extends Model
{
    protected $table = 'laundry_process_stocks';

    public static function booted()
    {
        // jab koi row get kry to business_id check ho
        static::addGlobalScope('business_check', function (Builder $builder) {
            $builder->where('business_id', auth()->user()->business_id);
        });
    }

    // jb inventory_item_id save ya update kry to business_id sath save ho
    public function setInventoryItemIdAttribute($value){
        $this->attributes['business_id'] = auth()->user()->business_id;
        $this->attributes['inventory_item_id'] = $value;
    }

    protected $fillable = [
        'rfid',
        'inventory_item_id',
        'status',
        'realloc',
        'note',
        'department_id',
        'subdepartment_id',
        'launder_id',
        'user_id',
        'business_id'
    ];

    public function business()
    {
        return $this->belongsTo(Business::class);
    }

    public function department($isSuperAdmin=false)
    {
        if($isSuperAdmin)
            return $this->belongsTo(Department::class, 'department_id')->withoutGlobalScope('business_check');
        else
            return $this->belongsTo(Department::class, 'department_id');
    }

    public function subdepartment($isSuperAdmin=false)
    {
        if($isSuperAdmin)
            return $this->belongsTo(Subdepartment::class, 'subdepartment_id')->withoutGlobalScope('business_check');
        else
            return $this->belongsTo(Subdepartment::class, 'subdepartment_id');
    }

    public function vendor($isSuperAdmin=false)
    {
        if($isSuperAdmin)
            return $this->belongsTo(Vendor::class, 'vendor_id')->withoutGlobalScope('business_check');
        else
            return $this->belongsTo(Vendor::class, 'vendor_id');
    }

    public function getPrityStatusAttribute(){
        switch ($this->status){
            case 'registered': return 'In Store';
            case 'issued': return 'Issued to '. $this->subdepartment->name;
            case 'returned': return 'In Store';
            case 'washing': return 'Sent for Laundry';
            case 'received': return 'Received';
            case 'washed': return 'Washed';
            case 'sent': return 'Sent';
            case 'washing_returned': return 'In Store';
            case 'damaged': return 'Damaged';
            case 'expired': return 'Expired';
            case 'lost': return 'Lost';
            case 'reallocated': return 'Re-allocated';
        }
    }

    public function inventory_item($isSuperAdmin=false)
    {
        if($isSuperAdmin)
            return $this->belongsTo(InventoryItem::class, 'inventory_item_id')->withoutGlobalScope('business_check')->with('inventory');
        else
            return $this->belongsTo(InventoryItem::class, 'inventory_item_id')->with('inventory');
    }

    public function scopeRFIDCount($query, $item)
    {
        $query->selectRaw('count(rfid) as rfid_count')->where('status','washing')->where('rfid',$item->rfid)->first();
    }
}
