<?php

namespace Modules\Laundry\Http\Controllers;
use Illuminate\Routing\Controller;
use Modules\Laundry\Entities\Inventory;
use Modules\Laundry\Entities\InventoryItem;
use Modules\Laundry\Entities\Category;
use Modules\Laundry\Entities\Subcategory;
use Modules\Laundry\Entities\Brand;
use Modules\Laundry\Entities\Supplier;
use Modules\Laundry\Entities\Department;
use Modules\Laundry\Entities\Subdepartment;
use Modules\Laundry\Entities\ProcessStock;
use Illuminate\Http\Request;


class InventoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */


     
    public function index()
    {
        
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            $r = auth()->user()->roleUser->role->rolesList->where('key','stock_view')->first();
            if($r!=null &&!$r->status)
                abort(404);
        }
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock List"]
        ];
        $inventories = Inventory::all();
        
        return view('laundry::content/inventory/index', ['breadcrumbs' => $breadcrumbs,
                'inventories' => $inventories,
                'table' => 'inventories']);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            $r = auth()->user()->roleUser->role->rolesList->where('key','stock_add')->first();
            if($r!=null && !$r->status)
                abort(404);
        }
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock list"], ['name'=>"Add"]
        ];
        $categories = Category::all();
        $subcategories = Subcategory::all();
        $brands = Brand::all();
        $suppliers = Supplier::all();
        $inventories = Inventory::all();
        
        return view('laundry::content/inventory/new', ['breadcrumbs' => $breadcrumbs,
                'categories' => $categories,
                'subcategories' => $subcategories,
                'brands' => $brands,
                'suppliers' => $suppliers,
                'inventories' => $inventories,
                'table' => 'inventories']);
        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    public function save(Request $request)
    {
        
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            $r = auth()->user()->roleUser->role->rolesList->where('key','stock_add')->first();
            if($r!==null && !$r->status)
                abort(404);
        }
        
        $request->validate([
            'category_id' => 'required|integer',
            'subcategory_id' => 'required|integer',
            'brand_id' => 'required|integer',
            'supplier_id' => 'required|integer',
            'washing_cost' => 'required|string|max:255',
            'washing_cycle' => 'required|string|max:255',
        ]);
        if($request->id){
            $inventory = Inventory::findOrFail($request->id);
            if(!$inventory) return redirect()->back()->with('message','Selected stock not found');
            $inventory->category_id = $request->category_id;
            $inventory->subcategory_id = $request->subcategory_id;
            $inventory->brand_id = $request->brand_id;
            $inventory->supplier_id = $request->supplier_id;
            $inventory->washing_cost = $request->washing_cost;
            $inventory->washing_cycle = $request->washing_cycle;
            $inventory->save();

            if($request->tags){
                $rfit_arr = explode(',',$request->tags);
                foreach($rfit_arr as $text){
                    InventoryItem::create([
                        'user_id' => auth()->user()->id,
                        'inventory_id' => $inventory->id,
                        'rfid' => $text
                    ]);
                }
            }

            return redirect()->back()->with('message','Stock updated successfully');
        }else{
            $inventory = Inventory::create([
                'category_id' => $request->category_id,
                'subcategory_id' => $request->subcategory_id,
                'brand_id' => $request->brand_id,
                'supplier_id' => $request->supplier_id,
                'washing_cost' => $request->washing_cost,
                'washing_cycle' => $request->washing_cycle,
            ]);

            if($inventory){
                $rfit_arr = explode(',',$request->tags);
                foreach($rfit_arr as $text){
                    $item = InventoryItem::create([
                        'user_id' => auth()->user()->id,
                        'inventory_id' => $inventory->id,
                        'rfid' => $text
                    ]);
                
                    $processStock = ProcessStock::create([
                        'user_id' => auth()->user()->id,
                        'rfid' => $text,
                        'inventory_item_id' => $item->id,
                        'status' => 'registered'
                    ]);
                }
            }

            return redirect()->back()->with('message','Stock added successfully');
        }
        
    }

    public function checkTag(Request $request){ // check if not aleady in the system and active
         $item = InventoryItem::where('rfid',$request->tag)->where('isActive', true)->first();
         if($item){
             return 'true';
         }else{
            return 'false';
         }
    }
    public function checkTagStatus(Request $request){ // check if not aleady in the system and active
        // $item = InventoryItem::where('rfid',$request->tag)->where('isActive', true)->first();
        $process = ProcessStock::where('rfid',$request->tag)->orderBy('id', 'desc')->first();
        if(!$process) return 'false';
        else return $process->status;
   }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function show(Inventory $inventory)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            $r = auth()->user()->roleUser->role->rolesList->where('key','stock_modify')->first();
            if($r!=null && !$r->status)
                abort(404);
        }
        
        $inventory = Inventory::findOrFail($id);
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock list"], ['name'=>"Edit"]
        ];
        $categories = Category::all();
        $subcategories = Subcategory::where('parent',$inventory->category_id)->get();
        $brands = Brand::all();
        $suppliers = Supplier::all();
        $inventories = Inventory::all();
        
        return view('laundry::content/inventory/edit', ['breadcrumbs' => $breadcrumbs,
        'categories' => $categories,
        'subcategories' => $subcategories,
        'brands' => $brands,
        'suppliers' => $suppliers,
        'inventories' => $inventories,
        'inventory' => $inventory,
        'table' => 'inventories']);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Inventory $inventory)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function destroy(Inventory $inventory)
    {
        //
    }
}
