<?php

namespace Modules\Laundry\Http\Controllers;
use Illuminate\Routing\Controller;
use Modules\Laundry\Entities\Inventory;
use Modules\Laundry\Entities\InventoryItem;
use Modules\Laundry\Entities\Category;
use Modules\Laundry\Entities\Subcategory;
use Modules\Laundry\Entities\Customer;
use Modules\Laundry\Entities\Department;
use Modules\Laundry\Entities\Subdepartment;
use Modules\Laundry\Entities\ProcessStock;
use Illuminate\Http\Request;


class InventoryLaunderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    //history
    public function index()
    {
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock List"]
        ];
        $inventories = Inventory::all();
        
        return view('laundry::content/inventorylaunder/index', ['breadcrumbs' => $breadcrumbs,
                'inventories' => $inventories,
                'table' => 'inventories']);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock list"], ['name'=>"Add"]
        ];
        $categories = Category::all();
        $subcategories = Subcategory::all();
        $customers = Customer::all();
        $inventories = Inventory::all();
        
        return view('laundry::content/inventorylaunder/new', ['breadcrumbs' => $breadcrumbs,
                'categories' => $categories,
                'subcategories' => $subcategories,
                'customers' => $customers,
                'inventories' => $inventories,
                'table' => 'inventories']);
        
    }

    public function createWash()
    {
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock list"], ['name'=>"Wash"]
        ];
        return view('laundry::content/inventorylaunder/change', ['breadcrumbs' => $breadcrumbs,
        'title' => 'Wash',
                'table' => 'inventories']);
        
    }
    public function createSent()
    {
       
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock list"], ['name'=>"Sent"]
        ];
        return view('laundry::content/inventorylaunder/change', ['breadcrumbs' => $breadcrumbs,
        'title' => 'Sent',
                'table' => 'inventories']);
        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    public function save(Request $request)
    {
        
        $request->validate([
            'category_id' => 'required|integer',
            'subcategory_id' => 'required|integer',
            'customer_id' => 'required|integer',
        ]);
        if($request->id){
            $inventory = Inventory::findOrFail($request->id);
            if(!$inventory) return redirect()->back()->with('message','Selected stock not found');
            $inventory->category_id = $request->category_id;
            $inventory->subcategory_id = $request->subcategory_id;
            $inventory->customer_id = $request->customer_id;
            $inventory->save();

            if($request->tags){
                $rfit_arr = explode(',',$request->tags);
                foreach($rfit_arr as $text){
                    InventoryItem::create([
                        'user_id' => auth()->user()->id,
                        'inventory_id' => $inventory->id,
                        'rfid' => $text
                    ]);
                }
            }

            return redirect()->back()->with('message','Stock updated successfully');
        }else{
            $inventory = Inventory::create([
                'category_id' => $request->category_id,
                'subcategory_id' => $request->subcategory_id,
                'customer_id' => $request->customer_id,
            ]);

            if($inventory){
                $rfit_arr = explode(',',$request->tags);
                foreach($rfit_arr as $text){
                    $item = InventoryItem::create([
                        'user_id' => auth()->user()->id,
                        'inventory_id' => $inventory->id,
                        'rfid' => $text
                    ]);
                
                    $processStock = ProcessStock::create([
                        'user_id' => auth()->user()->id,
                        'rfid' => $text,
                        'inventory_item_id' => $item->id,
                        'status' => 'received'
                    ]);
                }
            }

            return redirect()->back()->with('message','Stock received successfully');
        }
        
    }

    public function saveChangeStatus(Request $request)
    {
        
        $request->validate([ 
            'status' => 'required',
        ]);
  
        $rfit_arr = explode(',',$request->tags);
        foreach($rfit_arr as $text){
            $r = InventoryItem::where('rfid',$text)->first();
            if($r!=null){
                $rfid_id = $r->id;
                $processStock = ProcessStock::create([
                    'user_id' => auth()->user()->id,
                    'rfid' => $text,
                    'inventory_item_id' => $rfid_id,
                    'status' => $request->status
                ]); 
            }
               
        }

        return redirect()->back()->with('message','Staus changed to '.$request->status);
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function show(Inventory $inventory)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        
        $inventory = Inventory::findOrFail($id);
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock list"], ['name'=>"Edit"]
        ];

        

        $categories = Category::all();
        $subcategories = Subcategory::where('parent',$inventory->category_id)->get();
        $customers = Customer::all();
        $inventories = Inventory::all();

        return view('laundry::content/inventorylaunder/edit', ['breadcrumbs' => $breadcrumbs,
        'categories' => $categories,
        'subcategories' => $subcategories,
        'customers' => $customers,
        'inventories' => $inventories,
        'inventory' => $inventory,
        'table' => 'inventories']);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Inventory $inventory)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Inventory  $inventory
     * @return \Illuminate\Http\Response
     */
    public function destroy(Inventory $inventory)
    {
        //
    }
}
