<?php

namespace Modules\Laundry\Http\Controllers;
use Illuminate\Routing\Controller;
use Modules\Laundry\Entities\ProcessStock;
use Illuminate\Http\Request;
use Modules\Laundry\Entities\Department;
use Modules\Laundry\Entities\Category;
use Modules\Laundry\Entities\Subcategory;
use Modules\Laundry\Entities\Subdepartment;
use Modules\Laundry\Entities\InventoryItem;
use Modules\Laundry\Entities\Inventory;
use Modules\Laundry\Entities\Vendor;
use Carbon\Carbon;

class ProcessStockController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    public function issue()
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Stock list"], ['name'=>"Issue"]
        ];
        $departments = Department::all();
        
        return view('laundry::content/inventory/issue', ['breadcrumbs' => $breadcrumbs,
        'departments' => $departments,
        'table' => 'process_stocks']);
    }

    // for issue
    public function save(Request $request)
    {
        $validate = $request->validate([
                "tags_arr"    => "required|array|min:1",
                "tags_arr.*"  => "required|distinct|exists:inventory_items,rfid",
            ],
            [ // custom message
                'tags_arr.required'=> 'Please scan tags',
                'tags_arr.*.distinct'=> 'Duplicate tag found',
                'tags_arr.*.exists'=> 'Un-registered tag found',
            ]
        );

        foreach($request->tags_arr as $text){
            
            $item = ProcessStock::where('rfid',$text)->orderBy('id','desc')->first();
            if(!$item){
                return redirect()->back()->with('message','Item not available in the stock!');
            }else
            if($item->status!='registered' && $item->status!='returned' && $item->status!='washing_returned' ){
                return redirect()->back()->with('message','Item not available in the stock!');
            }
            

        }
        
        foreach($request->tags_arr as $text){
            $rfid_id = InventoryItem::where('rfid',$text)->first()->id;
            $processStock = ProcessStock::create([
                'department_id' => $request->department_id,
                'subdepartment_id' => $request->subdepartment_id,
                'user_id' => auth()->user()->id,
                'rfid' => $text,
                'inventory_item_id' => $rfid_id,
                'status' => 'issued'
            ]);
        }
        
        return redirect()->back()->with('message','Inventory issued successfully');
        
    }

    public function return()
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Department"], ['name'=>"Return"]
        ];
        return view('laundry::content/inventory/process', ['breadcrumbs' => $breadcrumbs,
        'title' => 'Return Stock',
        'purpose' => 'returned',
        'table' => 'process_stocks']);
    }

    public function washing()
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Inventory"], ['name'=>"Laundry"]
        ];

        // $launders = Vendor::where('status', '1')->get();
        $launders = auth()->user()->business->launders()->get();

        return view('laundry::content/inventory/process', ['breadcrumbs' => $breadcrumbs,
        'title' => 'Send to Laundry',
        'launders' => $launders,
        'purpose' => 'washing',
        'table' => 'process_stocks']);
    }

    public function washing_return()
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Inventory"], ['name'=>"Laundry"], ['name'=>"Return"]
        ];
        return view('laundry::content/inventory/process', ['breadcrumbs' => $breadcrumbs,
        'title' => 'Return from Laundry',
        'purpose' => 'washing_returned',
        'table' => 'process_stocks']);
    }

    public function process_save(Request $request)
    {
        $validate = $request->validate([
                'purpose' => 'required|string',
                'id' => 'required_without:tags_arr|string|exists:inventory_items',
                "tags_arr"    => "required_without:id|array|min:1",
                "tags_arr.*"  => "required|distinct|exists:inventory_items,rfid",
            ],
            [ // custom message
                'tags_arr.required'=> 'Please scan tags',
                'tags_arr.*.distinct'=> 'Duplicate tag found',
                'tags_arr.*.exists'=> 'Un-registered tag found',
            ]
        );

        // purpose = returned | washing | damaged | expired | lost | reallocated

        if($request->purpose=="returned"){
            // verify
            foreach($request->tags_arr as $text){
                $item = ProcessStock::where('rfid',$text)->orderBy('id','desc')->first();
                if(!$item){
                    return redirect()->back()->with('message','Item has not been issued to any department!');
                }else
                if($item->status!='issued'){
                    return redirect()->back()->with('message','Item  has not been issued to any department!');
                }
            }
            // update
            foreach($request->tags_arr as $text){
                $rfid_id = InventoryItem::where('rfid',$text)->first()->id;
                
                $processStock = ProcessStock::create([
                    'user_id' => auth()->user()->id,
                    'rfid' => $text,
                    'inventory_item_id' => $rfid_id,
                    'status' => 'returned'
                ]);
            }
            return redirect()->back()->with('message','Inventory returned successfully');
        }else



        if($request->purpose=="washing"){
            // verify
            foreach($request->tags_arr as $text){
                $item = ProcessStock::where('rfid',$text)->orderBy('id','desc')->first();
                if(!$item){
                    return redirect()->back()->with('message','Item not available in the stock!');
                }else
                if($item->status!='registered' && $item->status!='returned' && $item->status!='washing_returned' ){
                    return redirect()->back()->with('message','Item not available in the stock!');
                }
            }
            // update
            foreach($request->tags_arr as $text){
                $rfid_id = InventoryItem::where('rfid',$text)->first()->id;
                
                $processStock = ProcessStock::create([
                    'user_id' => auth()->user()->id,
                    'rfid' => $text,
                    'launder_id' => $request->launder_id,
                    'inventory_item_id' => $rfid_id,
                    'status' => 'washing'
                ]);
            }
            return redirect()->back()->with('message','Inventory sent for laundry successfully');
        }else



        if($request->purpose=="washing_returned"){
            // verify
            foreach($request->tags_arr as $text){
                $item = ProcessStock::where('rfid',$text)->orderBy('id','desc')->first();
                if(!$item){
                    return redirect()->back()->with('message','Item has not been sent for laundry!');
                }else
                if($item->status!='washing'){
                    return redirect()->back()->with('message','Item has not been sent for laundry!');
                }
            }
            // update
            foreach($request->tags_arr as $text){
                $rfid_id = InventoryItem::where('rfid',$text)->first()->id;
                
                $processStock = ProcessStock::create([
                    'user_id' => auth()->user()->id,
                    'rfid' => $text,
                    'inventory_item_id' => $rfid_id,
                    'status' => 'washing_returned'
                ]);
            }
            return redirect()->back()->with('message','Inventory returned from laundry successfully');
        }else


        if($request->purpose=="damaged"
            || $request->purpose=="expired"
            || $request->purpose=="lost"){
            // update

            // if($request->tags_arr) // if array of tags
            //     foreach($request->tags_arr as $text){
            //         $item = InventoryItem::where('rfid',$text)->first();
            //         $lastProcess = $item->process_stock->last();
            //         $processStock = ProcessStock::create([
            //             'user_id' => auth()->user()->id,
            //             'rfid' => $text,
            //             'inventory_item_id' => $item->id,
            //             'status' => $request->purpose,
            //             'note' => $request->note,
            //             'department_id' => $lastProcess->department_id,
            //             'subdepartment_id' => $lastProcess->subdepartment_id,
            //             'vendor_id' => $lastProcess->vendor_id
            //         ]);
            //     }
            // else{ // in single tag

                $isReallocated = $request->reallocated=='true' ? true : false;

                $item = InventoryItem::find($request->id);
                $lastProcess = $item->process_stock->last();
                $processStock = ProcessStock::create([
                    'user_id' => auth()->user()->id,
                    'rfid' => $item->rfid,
                    'inventory_item_id' => $item->id,
                    'status' => $request->purpose,
                    'realloc' => $isReallocated,
                    'note' => $request->note,
                    'department_id' => $lastProcess->department_id,
                    'subdepartment_id' => $lastProcess->subdepartment_id,
                    'vendor_id' => $lastProcess->vendor_id
                ]);

                if($isReallocated){
                    $item->isActive = false;
                    $item->save();
                    // ProcessStock::where('rfid', $item->rfid)->update(['rfid' => null]);
                }
            // }

            return redirect()->back()->with('message','Item status changed to '. $request->purpose);
        }

        return redirect()->back()->with('message','Unknown purpose.');
        
    }


    /**
     * Reports
     *
     */

    public function status_report(Request $request)
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Reports"], ['name'=>"Inventory Status"]
        ];
        
        $cat = $request->cat;
        $subcat = $request->subcat;

        if(!$cat)
            $items = InventoryItem::all();
        else
        if($cat && !$subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat){
                $q->where('category_id', $cat);
            })->get();
        }else
        if($cat && $subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat, $subcat){
                $q->where('category_id', $cat)->where('subcategory_id', $subcat);
            })->get();
        }
            
        $categories = Category::all();

        return view('laundry::content/inventory-reports/status', ['breadcrumbs' => $breadcrumbs,
            'categories' => $categories,
            'items' => $items,
            'table' => 'process_stocks']);
    }

    public function cost_report(Request $request)
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Reports"], ['name'=>"Cost Reports"],
        ];
        
        $cat = $request->cat;
        $subcat = $request->subcat;
        $fromDate = $toDate = '';

        if($request->range){
            if(!str_contains($request->range,' to ')){
                $fromDate = $request->range;
                $toDate = $request->range;
            }else{
                $range_ar = explode(' to ', $request->range);
                $fromDate = $range_ar[0];
                $toDate = $range_ar[1];
            }
        }

        if(!$cat)
            $items = InventoryItem::all();
        else
        if($cat && !$subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat){
                $q->where('category_id', $cat);
            })->get();
        }else
        if($cat && $subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat, $subcat){
                $q->where('category_id', $cat)->where('subcategory_id', $subcat);
            })->get();
        }
            
        $categories = Category::all();

        return view('laundry::content/inventory-reports/cost', ['breadcrumbs' => $breadcrumbs,
            'categories' => $categories,
            'items' => $items,
            'fromDate' => $fromDate,
            'toDate' => $toDate,
            'table' => 'process_stocks']);
    }

    public function depreciation_report(Request $request)
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Reports"], ['name'=>"Depreciation Reports"],
        ];
        
        $cat = $request->cat;
        $subcat = $request->subcat;
        

        if(!$cat)
            $items = InventoryItem::all();
        else
        if($cat && !$subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat){
                $q->where('category_id', $cat);
            })->get();
        }else
        if($cat && $subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat, $subcat){
                $q->where('category_id', $cat)->where('subcategory_id', $subcat);
            })->get();
        }
            
        $categories = Category::all();

        return view('laundry::content/inventory-reports/depreciation', ['breadcrumbs' => $breadcrumbs,
            'categories' => $categories,
            'items' => $items,
            'table' => 'process_stocks']);
    }

    public function month_report(Request $request)
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Reports"], ['name'=>"Month Reports"],
        ];
        
        $year = $request->y??'2022';
        $month = $request->m??'01';
           
        $date = Carbon::parse($year.'-'.$month.'-01');
        $sDate = $date->format('Y-m-d H:i:s');
        $eDate = $date->endOfMonth()->format('Y-m-d H:i:s');

        $subcategories = Subcategory::all();
        $rows = [];

        $i=0;
        foreach($subcategories as $subcategory){
            $i++;
            $row['serial'] = $subcategory->id;
            $row['name'] = $subcategory->name;
            $row['registered'] = $subcategory->inventories
                                    ->whereBetween('created_at',[$sDate, $eDate])
                                    ->sum('quantity');
            $tWasing = 0;
            $tWasingCost = 0;
            $tExpired = 0;
            $tDamaged = 0;
            $tLost = 0;
            foreach($subcategory->inventories as $inventory){
                foreach($inventory->items as $item){
                    $processes = $item->process_stock
                                ->whereBetween('created_at',[$sDate, $eDate]);
                    
                    $processesWashing = $processes->where('status','washing');
                    $tWasing+= $processesWashing->count();
                    $tWasingCost+= $processesWashing->count() * $inventory->washing_cost;

                    $tExpired+= $processes->where('status','expired')->count();
                    $tDamaged+= $processes->where('status','damaged')->count();
                    $tLost+= $processes->where('status','lost')->count();
                }
                
            }
            $row['t_washes'] = $tWasing;       
            $row['t_washes_cost'] = $tWasingCost;  
            $row['t_expired'] = $tExpired;  
            $row['t_damaged'] = $tDamaged;  
            $row['t_lost'] = $tLost;        


            $rows[] = $row;
        }

        return view('laundry::content/inventory-reports/month', ['breadcrumbs' => $breadcrumbs,
            'rows' => $rows,
            'table' => 'categories']);
    }


    public function lost_damage_report(Request $request)
    {
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Reports"], ['name'=>"Lost Damage Report"]
        ];
        
        $cat = $request->cat;
        $subcat = $request->subcat;

        if(!$cat)
            $items = InventoryItem::all();
        else
        if($cat && !$subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat){
                $q->where('category_id', $cat);
            })->get();
        }else
        if($cat && $subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat, $subcat){
                $q->where('category_id', $cat)->where('subcategory_id', $subcat);
            })->get();
        }
            
        $categories = Category::all();

        return view('laundry::content/inventory-reports/lost_damage', ['breadcrumbs' => $breadcrumbs,
            'categories' => $categories,
            'items' => $items,
            'table' => 'process_stocks']);
    }

    public function single_status_report(Request $request)
    {
        $type = last(request()->segments());
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Reports"], ['name'=> $type." Report"]
        ];
        
        $cat = $request->cat;
        $subcat = $request->subcat;

        if(!$cat)
            $items = InventoryItem::all();
        else
        if($cat && !$subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat){
                $q->where('category_id', $cat);
            })->get();
        }else
        if($cat && $subcat){
            $items = InventoryItem::with('inventory')->whereHas('Inventory', function($q) use ($cat, $subcat){
                $q->where('category_id', $cat)->where('subcategory_id', $subcat);
            })->get();
        }
            
        $categories = Category::all();

        return view('laundry::content/inventory-reports/single_status', ['breadcrumbs' => $breadcrumbs,
            'categories' => $categories,
            'items' => $items,
            'type' => $type,
            'table' => 'process_stocks']);
    }


    public function states_json(Request $request)
    {
        $available = 0;
        $lostdamagedexpired = 0;
        $itemsCount = 0;
        $wasingCost = 0;
        $inuse = 0;
        $inwashing = 0;
        $monthly_washings = [];

        if(auth()->user()->id==1) // This is the super admin
            $items = InventoryItem::withoutGlobalScope('business_check')->get();
        else
            $items = InventoryItem::get();
        
        foreach($items as $item){
            if(auth()->user()->id==1)
                $status = $item->process_stock(true)->get()->last()->status;
            else
                $status = $item->process_stock->last()->status;
            if($status=='registered' || $status=='returned' || $status=='washing_returned')
                $available++;
            else
            if($status=='lost' || $status=='damaged' || $status=='expired')
                $lostdamagedexpired++;
            else
            if($status=='issued')
                $inuse++;
            else
            if($status=='washing')
                $inwashing++;

            if(auth()->user()->id==1){
                $processesWashing = $item->process_stock_washing(true)->get();
                $wasingCost+= $processesWashing->count() * $item->inventory(true)->first()->washing_cost;
            }
            else{
                $processesWashing = $item->process_stock_washing;
                $wasingCost+= $processesWashing->count() * $item->inventory->washing_cost;
            }
        }

        $itemsCount = $items->count() - $lostdamagedexpired;


        // monthly_washing count and cost
        for ($i = 11; $i >= 0; $i--) {
            $month = Carbon::today()->startOfMonth()->subMonth($i);
            $year =  $month->format('Y');

            if(auth()->user()->id==1){
                $prcesses_washing = ProcessStock::withoutGlobalScope('business_check')
                    ->where('status','washing')
                    ->whereBetween('created_at',[$month->format('Y-m-d H:i:s'),
                                                $month->endOfMonth()->format('Y-m-d H:i:s')])
                                                ->get();
            }else{
                $prcesses_washing = ProcessStock::where('status','washing')
                    ->whereBetween('created_at',[$month->format('Y-m-d H:i:s'),
                                                $month->endOfMonth()->format('Y-m-d H:i:s')])
                                                ->get();
            }

            $cost = 0;
            foreach($prcesses_washing as $process){
                if(auth()->user()->id==1){
                    $ii = $process->inventory_item(true)->first();
                    if($ii!=null){
                        $cost+= $ii->inventory(true)->first()->washing_cost;
                    }else{
                        $cost+= $process->inventory_item->inventory->washing_cost;
                    }
                    
                }else{
                    $cost+= $process->inventory_item->inventory->washing_cost;
                }
            }
            
            array_push($monthly_washings, array(
                'washing_count' => $prcesses_washing->count(),
                'washing_cost' => $cost,
                'month' => $month->shortMonthName,
                'year' => $year
            ));
        }


        return response()->json([
                'error' => false,
                'message' => '',
                'data' => ['in_stock' => $available,
                    'lost_damaged_expired' => $lostdamagedexpired,
                    'total_items' => $itemsCount,
                    'washing_cost' => $wasingCost,
                    'ready_to_use' => $available,
                    'in_use' => $inuse,
                    'in_washing' => $inwashing,
                    'monthly_washing' => $monthly_washings]
            ]);
    
    
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\ProcessStock  $processStock
     * @return \Illuminate\Http\Response
     */
    public function show(ProcessStock $processStock)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\ProcessStock  $processStock
     * @return \Illuminate\Http\Response
     */
    public function edit(ProcessStock $processStock)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\ProcessStock  $processStock
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, ProcessStock $processStock)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\ProcessStock  $processStock
     * @return \Illuminate\Http\Response
     */
    public function destroy(ProcessStock $processStock)
    {
        //
    }
}
