<?php

namespace Modules\Laundry\Http\Controllers;
use Illuminate\Routing\Controller;
use Modules\Laundry\Entities\Department;
use Modules\Laundry\Entities\Subdepartment;
use Illuminate\Http\Request;

class SubdepartmentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(){
        
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            $r = auth()->user()->roleUser->role->rolesList->where('key','subdepartments_view')->first();
            if($r!=null && $r->status)
                abort(404);
        }
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Index"]
        ];
        $parents = Department::all();
        $subdepartments = Subdepartment::all();
        
        return view('laundry::content/subdepartment/index', ['breadcrumbs' => $breadcrumbs,
        'parents' => $parents,
        'subdepartments' => $subdepartments,
        'table' => 'subdepartments']);
    }

    public function subdepartmentList(Request $request){
        $subdepartments = Subdepartment::where('parent',$request->id)->get();
        $html = "";
        foreach ($subdepartments as $subdepartment){
            $html .= '<option value="'.$subdepartment->id.'">'.$subdepartment->name.'</option>';
        }
        return $html;
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
    }

    public function save(Request $request)
    {
        
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            $r = auth()->user()->roleUser->role->rolesList->where('key','subdepartments_add')->first();
            if($r!=null && $r->status)
                abort(404);
        }
        
        $request->validate([
            'parent' => 'required|integer',
            'name' => 'required|string|max:255',
        ]);
        if($request->id){
            $department = Subdepartment::findOrFail($request->id);
            $department->parent = $request->parent;
            $department->name = $request->name;
            $department->name_ar = $request->name_ar;
            $department->save();
            return redirect()->back()->with('message','Sub Department updated successfully');
        }else{
            Subdepartment::create([
                'parent' => $request->parent,
                'name' => $request->name,
                'name_ar' => $request->name_ar,
                'status' => 1
            ]);
            return redirect()->back()->with('message','New sub department added successfully');
        }
        
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Department  $department
     * @return \Illuminate\Http\Response
     */
    public function show(Department $department)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Department  $department
     * @return \Illuminate\Http\Response
     */
    public function edit(Department $department)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Department  $department
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Department $department)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Department  $department
     * @return \Illuminate\Http\Response
     */
    public function destroy(Department $department)
    {
        //
    }
}
