<?php

namespace Modules\Laundry\Http\Controllers;
use Illuminate\Routing\Controller;
use Modules\Laundry\Entities\User;
use Modules\Laundry\Entities\Business;
use Modules\Laundry\Entities\Department;
use Modules\Laundry\Entities\Category;
use Modules\Laundry\Entities\Subcategory;
use Modules\Laundry\Entities\Role;
use Modules\Laundry\Entities\RoleUser;
use Modules\Laundry\Entities\RoleTable;
use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Request;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function hospitalIndex()
    {
        if(auth()->user()->id!=1) return '';

        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Hospitals"]
        ];
        // $users = User::where('isAdmin',true)->get();
        $users = User::where('isAdmin',true)->whereHas('business', function($query){
            return $query->whereHas('business_type', function($query){
                return $query->where('id',1);
            });
        })->get();
        
        return view('laundry::content/clients/index', ['breadcrumbs' => $breadcrumbs,
        'users' => $users,
        'title' => 'Hospital',
        'table' => 'users']);
    }
    public function hotelIndex()
    {
        if(auth()->user()->id!=1) return '';

        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Hotels"]
        ];
        // $users = User::where('isAdmin',true)->get();
        $users = User::where('isAdmin',true)->whereHas('business', function($query){
            return $query->whereHas('business_type', function($query){
                return $query->where('id',2);
            });
        })->get();
        
        return view('laundry::content/clients/index', ['breadcrumbs' => $breadcrumbs,
        'users' => $users,
        'title' => 'Hotel',
        'table' => 'users']);
    }
    
    public function laundersIndex()
    {
        if(auth()->user()->id!=1) return '';

        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Launder"]
        ];
        // $users = User::where('isAdmin',true)->get();
        $users = User::all();
        
        return view('laundry::content/clients/index', ['breadcrumbs' => $breadcrumbs,
        'users' => $users,
        'title' => 'Launder',
        'table' => 'users']);
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($id=0)
    {
        
        if(auth()->user()->id!=1){
            abort(404);
        }
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Clients list"], ['name'=>"Add"]
        ];
        
        $user = null;
        if($id!=0) $user = User::findOrFail($id);


        return view('laundry::content/clients/new', ['breadcrumbs' => $breadcrumbs,
        'user' => $user,
        'table' => 'users']);
    }

    public function save(Request $request)
    {
        if(auth()->user()->id!=1){
            abort(404);
        }

        $request->validate([
            'business_name' => 'required|string|max:255',
            'business_name_ar' => 'nullable|string|max:255',
            'business_phone' => 'required|string|max:255',
            'business_email' => 'required|string|max:255',
            'business_expiry' => 'required|date',
            'business_address' => 'required|string|max:255',
            'name' => 'required|string|max:255',
            'phone' => 'required|string|max:255',
            'email' => 'required|email',
            'password' => 'nullable|string|min:8',
        ]);
        if($request->id){
            $user = User::findOrFail($request->id);
            $user->name = $request->name;
            $user->phone = $request->phone;
            $user->email = $request->email;
            $user->status = $request->enabled ? true : false;
            if($request->password) $user->password = Hash::make($request->password);
            $user->save();

            $business = $user->business;
            $business->name = $request->business_name;
            $business->name_ar = $request->business_name_ar;
            $business->phone = $request->business_phone;
            $business->expired_at = $request->business_expiry;
            $business->address = $request->business_address;
            $business->email = $request->business_email;
            $business->status = $request->enabled ? true : false;
            $business->save();

            return redirect()->back()->with('message','Business and Admin updated successfully');
        }else{
            $business = Business::create([
                'name' => $request->business_name,
                'name_ar' => $request->business_name_ar,
                'phone' => $request->business_phone,
                'expired_at' => $request->business_expiry,
                'address' => $request->business_address,
                'email' => $request->business_email,
            ]);
            $user = User::create([
                'name' => $request->name,
                'phone' => $request->phone,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'isAdmin' => true,
                'business_id' => $business->id
            ]);

            if($request->business_type_id==1){
                // Add default listings, brands categories etc
                $depart1 = Department::create(['name' => 'Test Department']);
                $depart1->business_id = $business->id;
                $depart1->save();

                $cat1 = Category::create(['name' => 'Test Category']);
                $cat1->business_id = $business->id;
                $cat1->save();

                $subcat1 = Subcategory::create([
                    'name' => 'Test Sub Category',
                    'parent' => $cat1->id
                ]);
                $subcat1->business_id = $business->id;
                $subcat1->save();
            }

            return redirect()->back()->with('message','Business and Admin created');
        }
    }


    public function listMyLaunder()
    {
        if(auth()->user()->business->business_type_id!=1 && auth()->user()->business->business_type_id!=2){
            abort(404);
        }

        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Launders"]
        ];

        $business = auth()->user()->business->launders()->get();
        // $business2 = auth()->user()->business->owners()->get();

        return view('laundry::content/mylaunders/index', ['breadcrumbs' => $breadcrumbs,
        'business' => $business,
        'title' => 'Launder',
        'table' => 'business']);
    }
    public function createMyLaunder($id=0)
    {
        if(auth()->user()->business->business_type_id!=1 && auth()->user()->business->business_type_id!=2){
            abort(404);
        }
        
        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"My Laundries list"], ['name'=>"Add"]
        ];
        
        $user = null;
        if($id!=0){
            $business = Business::findOrFail($id);
            $user = $business->users[0];
        }

        return view('laundry::content/mylaunders/new', ['breadcrumbs' => $breadcrumbs,
        'user' => $user,
        'table' => 'users']);
    }

    public function saveMyLaunder(Request $request)
    {
        if(auth()->user()->business->business_type_id!=1 && auth()->user()->business->business_type_id!=2){
            abort(404);
        }

        $request->validate([
            'business_name' => 'required|string|max:255',
            'business_name_ar' => 'nullable|string|max:255',
            'business_phone' => 'required|string|max:255',
            'business_email' => 'required|string|max:255',
            'business_address' => 'required|string|max:255',
            'name' => 'required|string|max:255',
            'phone' => 'required|string|max:255',
            'email' => 'required|email',
            'password' => 'nullable|string|min:8',
        ]);
        if($request->id){
            $user = User::findOrFail($request->id);
            $user->name = $request->name;
            $user->phone = $request->phone;
            $user->email = $request->email;
            $user->status = $request->enabled ? true : false;
            if($request->password) $user->password = Hash::make($request->password);
            $user->save();

            $business = $user->business;
            $business->name = $request->business_name;
            $business->name_ar = $request->business_name_ar;
            $business->phone = $request->business_phone;
            $business->address = $request->business_address;
            $business->email = $request->business_email;
            $business->status = $request->enabled ? true : false;
            $business->save();

            return redirect()->back()->with('message','Laundry and User updated successfully');
        }else{
            $business = Business::create([
                'name' => $request->business_name,
                'name_ar' => $request->business_name_ar,
                'business_type_id' => 3, // business id 3 is laundery
                'phone' => $request->business_phone,
                'expired_at' => \Carbon\Carbon::now()->addYear()->toDateString(),
                'address' => $request->business_address,
                'email' => $request->business_email,
            ]);
            $user = User::create([
                'name' => $request->name,
                'phone' => $request->phone,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'isAdmin' => true,
                'business_id' => $business->id
            ]);

            auth()->user()->business->launders()->attach($business->id);

            return redirect()->back()->with('message','Laundry and User created');
        }
    }


    public function roleUsersList()
    {
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            abort(404);
        }

        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"Role"]
        ];
        $business_id = auth()->user()->business_id;
        $users = User::where('isAdmin', false)->get();
        
        return view('laundry::content/role/index', ['breadcrumbs' => $breadcrumbs,
        'users' => $users,
        'table' => 'roles']);
    }

    public function roleCreate($id=0)
    {
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            abort(404);
        }

        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"User Roles"], ['name'=>"Add"]
        ];
        
        $user = null;
        if($id!=0) $user = User::where('id', $id)->first();

        $roles = Role::where('name','!=','Admin')->get();

        if($roles->count()==0){
            Role::create([
                'name' => 'User'
            ]);
            $roles = Role::where('name','!=','Admin')->get();
        }

        return view('laundry::content/role/new', ['breadcrumbs' => $breadcrumbs,
        'user' => $user,
        'roles' => $roles,
        'table' => 'roles']);
    }

    public function roleSave(Request $request)
    {
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            abort(404);
        }

        $request->validate([
            'role_id' => 'required',
            'name' => 'required|string|max:255',
            'phone' => 'required|string|max:255',
            'email' => 'required|email',
            'password' => 'nullable|string|min:8',
        ]);
        if($request->id){
            $user = User::findOrFail($request->id);
            $user->name = $request->name;
            $user->phone = $request->phone;
            $user->email = $request->email;
            $user->isAdmin = false;
            $user->status = $request->enabled ? true : false;
            if($request->password) $user->password = Hash::make($request->password);
            $user->save();

            $roleUser = RoleUser::where('user_id',$user->id)->first();
            $roleUser->role_id = $request->role_id;
            $roleUser->save();

            return redirect()->back()->with('message','User and role updated successfully');
        }else{
            
            $user = User::create([
                'name' => $request->name,
                'phone' => $request->phone,
                'email' => $request->email,
                'isAdmin' => false,
                'password' => Hash::make($request->password),
                'business_id' => auth()->user()->business_id
            ]);

            RoleUser::create([
                'role_id' => $request->role_id,
                'user_id' => $user->id
            ]);

            return redirect()->back()->with('message','User created');
        }
    }

    public function roleList()
    {
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            abort(404);
        }

        $breadcrumbs = [
            ['link'=>"home",'name'=>"Home"], ['name'=>"User Roles"], ['name'=>"Manage"]
        ];
        
        $roleDetails = RoleTable::all();

        $role = Role::where('name','!=','Admin')->first();
            
        if($role && $roleDetails->count() == 0){
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'departments_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'departments_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'departments_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'subdepartments_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'subdepartments_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'subdepartments_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'brands_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'brands_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'brands_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'vendors_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'vendors_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'vendors_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'suppliers_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'suppliers_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'suppliers_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'categories_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'categories_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'categories_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'subcategories_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'subcategories_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'subcategories_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'stock_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'stock_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'stock_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'issue_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'issue_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'issue_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'return_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'return_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'return_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'washing_go_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'washing_go_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'washing_go_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'washing_back_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'washing_back_add']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'washing_back_modify']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'report_cost_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'report_depreciation_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'report_status_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'report_lostdamage_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'report_month_view']);
            RoleTable::create(['status' => 1,'role_id' => $role->id,'key' => 'report_settings_view']);
            $roleDetails = RoleTable::all();
        }

        
        return view('laundry::content/role/roles', ['breadcrumbs' => $breadcrumbs,
        'roleDetails' => $roleDetails,
        'table' => 'roles']);
    }

    public function roleManageSave(Request $request)
    {
        if(!auth()->user()->isAdmin && auth()->user()->id!=1){
            abort(404);
        }

        $roles = RoleTable::all();
        
        foreach($roles as $role){
            $role->status = 0;
            $role->save();
        }

        foreach ($request->all() as $key => $value){
            if($key != '_token'){
                $row = RoleTable::where('key', $key)->first();
                $row->status = 1;
                $row->save();   
            }
        }

        return redirect()->back()->with('message','Roles updated');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Supplier  $supplier
     * @return \Illuminate\Http\Response
     */
    public function show(Supplier $supplier)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Supplier  $supplier
     * @return \Illuminate\Http\Response
     */
    public function edit(Supplier $supplier)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Supplier  $supplier
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Supplier $supplier)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Supplier  $supplier
     * @return \Illuminate\Http\Response
     */
    public function destroy(Supplier $supplier)
    {
        //
    }
}
