<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
use Modules\Laundry\Http\Controllers\ScanStockController;

use Illuminate\Support\Facades\Route;
use Modules\Laundry\Http\Controllers\StaterkitController;
use Modules\Laundry\Http\Controllers\DepartmentController;
use Modules\Laundry\Http\Controllers\SubdepartmentController;
use Modules\Laundry\Http\Controllers\BrandController;
use Modules\Laundry\Http\Controllers\VendorController;
use Modules\Laundry\Http\Controllers\SupplierController;
use Modules\Laundry\Http\Controllers\CategoryController;
use Modules\Laundry\Http\Controllers\SubcategoryController;
use Modules\Laundry\Http\Controllers\LanguageController;
use Modules\Laundry\Http\Controllers\InventoryController;
use Modules\Laundry\Http\Controllers\InventoryLaunderController;
use Modules\Laundry\Http\Controllers\ProcessStockController;
use Modules\Laundry\Http\Controllers\ProcessStockLaunderController;
use Modules\Laundry\Http\Controllers\UserController;
use Modules\Laundry\Http\Controllers\CustomerController;

Route::prefix('laundry')->group(function() {
    Route::get('/test', function(){
        return 'test';
    });

    Route::get('/stock/add-scan-stock', [ScanStockController::class, 'addScanStock']);
    Route::get('/stock/get-scan-stock', [ScanStockController::class, 'getScanStock']);
    // Route::get('/', 'LaundryController@index');
    // Route::get('/', 'StaterkitController@home');
    

    Route::group([
        'middleware' => 'auth'
    ], function () {

        Route::get('/business-id', function(){
            return auth()->user()->business_id;
        });
        
        Route::get('/', [StaterkitController::class, 'home'])->name('home');
        
        Route::post('stock/check-tag', [InventoryController::class, 'checkTag']);
        Route::post('stock/check-tag-status', [InventoryController::class, 'checkTagStatus']);
        
        Route::get('hospitals', [UserController::class, 'hospitalIndex'])->name('hospitals');
        Route::get('hotels', [UserController::class, 'hotelIndex'])->name('hotels');
        Route::get('launders', [UserController::class, 'laundersIndex'])->name('launders');
        
        // Super creates clients
        Route::get('clients/add/{id}', [UserController::class, 'create'])->name('newclient');
        Route::get('clients/add', [UserController::class, 'create'])->name('newclients');
        Route::post('clients/save', [UserController::class, 'save'])->name('savenewclients');

        // Hospital/Hotels creates launders in users table
        Route::get('my-launders/add/{id}', [UserController::class, 'createMyLaunder'])->name('newmylaunder');
        Route::get('my-launders/add', [UserController::class, 'createMyLaunder'])->name('newmylaunder');
        Route::post('my-launders/save', [UserController::class, 'saveMyLaunder'])->name('savenewmylaunder');
        Route::get('my-launders', [UserController::class, 'listMyLaunder'])->name('listmylaunder');

        Route::get('roles', [UserController::class, 'roleUsersList'])->name('role');
        Route::get('roles/add/{id}', [UserController::class, 'roleCreate'])->name('rolenewlient');
        Route::get('roles/add', [UserController::class, 'roleCreate'])->name('rolenewlient');
        Route::post('roles/save', [UserController::class, 'roleSave'])->name('rolesavenewclients');
        Route::get('roles/manage', [UserController::class, 'roleList'])->name('rolesavenewclients');
        Route::post('roles/manage-update', [UserController::class, 'roleManageSave'])->name('savenewclients');

        Route::get('clients/login-as/{id}', function($id){
            if(auth()->user()->id==1){
                Auth::loginUsingId($id);
                return redirect()->to('/')->with('message', 'Now you are using the Smart Laundry as '. auth()->user()->business->name);
            }else{
                return abort(404);
            }

        })->name('loginas');

        Route::post('/logout', [LoginController::class, 'logout']);            
        
        Route::get('home', [StaterkitController::class, 'home'])->name('home');

        Route::get('departments', [DepartmentController::class, 'index'])->name('departments');
        Route::post('departments/save', [DepartmentController::class, 'save'])->name('home');
        
        Route::get('subdeptList', [SubdepartmentController::class, 'subdepartmentList'])->name('subdepartmentsList');
        Route::get('subdepartments', [SubdepartmentController::class, 'index'])->name('subdepartments');
        Route::post('subdepartments/save', [SubdepartmentController::class, 'save'])->name('home');
        
        Route::get('brands', [BrandController::class, 'index'])->name('brands');
        Route::post('brands/save', [BrandController::class, 'save']);
        
        // Route::get('_vendors', [VendorController::class, 'index'])->name('vendors');
        // Route::post('_vendors/save', [VendorController::class, 'save']);
        
        Route::get('suppliers', [SupplierController::class, 'index'])->name('suppliers');
        Route::post('suppliers/save', [SupplierController::class, 'save']);
        
        Route::get('categories', [CategoryController::class, 'index'])->name('categories');
        Route::post('categories/save', [CategoryController::class, 'save']);
        
        Route::get('subcatList', [SubcategoryController::class, 'subcategoriesList'])->name('subcategoriesList');
        Route::get('subcategories', [SubcategoryController::class, 'index'])->name('subcategories');
        Route::post('subcategories/save', [SubcategoryController::class, 'save']);
        
        Route::get('stock/add/{id}', [InventoryController::class, 'edit'])->name('editstock');
        Route::get('stock/add', [InventoryController::class, 'create'])->name('newstock');
        Route::post('stock/save', [InventoryController::class, 'save']);
        Route::get('stock', [InventoryController::class, 'index'])->name('stock');
        
        Route::get('stock/issue', [ProcessStockController::class, 'issue'])->name('issuestock');
        Route::post('stock/issue/save', [ProcessStockController::class, 'save'])->name('issue_save');
        
        Route::get('stock/return', [ProcessStockController::class, 'return'])->name('returnstock');
        Route::get('stock/washing', [ProcessStockController::class, 'washing'])->name('washing');
        Route::get('stock/washing/return', [ProcessStockController::class, 'washing_return'])->name('washingreturn');
        
        Route::post('stock/process/save', [ProcessStockController::class, 'process_save'])->name('return_save');
        
        Route::get('reports/status', [ProcessStockController::class, 'status_report'])->name('statusreport');
        Route::get('reports/cost', [ProcessStockController::class, 'cost_report'])->name('costreport');
        Route::get('reports/depreciation', [ProcessStockController::class, 'depreciation_report'])->name('depreciationreport');
        Route::get('reports/month', [ProcessStockController::class, 'month_report'])->name('monthreport');
        Route::get('reports/lost-damage', [ProcessStockController::class, 'lost_damage_report'])->name('lostdamagereport');



        // Launder routes
        Route::get('customers', [CustomerController::class, 'index'])->name('customers');
        Route::post('customers/save', [CustomerController::class, 'save']);

        Route::get('launder-stock', [InventoryLaunderController::class, 'index'])->name('history');
        Route::get('launder-stock/add/{id}', [InventoryLaunderController::class, 'edit'])->name('editstock');
        Route::get('launder-stock/add', [InventoryLaunderController::class, 'create'])->name('newstock');
        Route::get('launder-stock/wash', [InventoryLaunderController::class, 'createWash'])->name('washstock');
        Route::get('launder-stock/sent', [InventoryLaunderController::class, 'createSent'])->name('washstock');
        Route::post('launder-stock/save', [InventoryLaunderController::class, 'save']);
        Route::post('launder-stock/change-status', [InventoryLaunderController::class, 'saveChangeStatus']);
        
        Route::get('launder-reports/received', [ProcessStockController::class, 'single_status_report'])->name('single_status_report');
        Route::get('launder-reports/washed', [ProcessStockController::class, 'single_status_report'])->name('single_status_report');
        Route::get('launder-reports/sent', [ProcessStockController::class, 'single_status_report'])->name('single_status_report');
        // Route::get('stock/washing', [ProcessStockController::class, 'washing'])->name('washing');

        Route::get('launder-reports/status', [ProcessStockController::class, 'status_report'])->name('statusreport');


    });

});
